==> haskell-selective-0.7.0.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 selective
version:              0.7.0.1
visibility:           public
id:                   selective-0.7.0.1-7b1x7hemSGAJOgXwxFC8oK
key:                  selective-0.7.0.1-7b1x7hemSGAJOgXwxFC8oK
license:              MIT
copyright:            Andrey Mokhov, 2018-2024
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://dl.acm.org/doi/10.1145/3341694 this paper>.

category:             Control
abi:                  030bf23482af60266b1bf2bf680eb21e
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Control.Selective.Trans.Except

import-dirs:          /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-selective
hs-libraries:         HSselective-0.7.0.1-7b1x7hemSGAJOgXwxFC8oK
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-selective-0.7.0.1-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 selective
version:              0.7.0.1
visibility:           public
id:                   selective-0.7.0.1-81rwBG2AfpIIRj4fpfj6Yv
key:                  selective-0.7.0.1-81rwBG2AfpIIRj4fpfj6Yv
license:              MIT
copyright:            Andrey Mokhov, 2018-2024
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://dl.acm.org/doi/10.1145/3341694 this paper>.

category:             Control
abi:                  dbd4377ed72fb97153e831abadf846c8
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Control.Selective.Trans.Except

import-dirs:          /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-selective
hs-libraries:         HSselective-0.7.0.1-81rwBG2AfpIIRj4fpfj6Yv
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
